@@ -1,9 +1,10 @@
 # -*- coding: utf-8 -*-
 from __future__ import print_function
 from functools import partial
-import httplib2
 import json
-from six.moves.urllib.parse import quote
+from urllib.parse import quote
+import requests
+from requests.auth import HTTPBasicAuth
 
 """
 This module contains classes for interacting with the BibSonomy REST API.
@@ -374,24 +375,22 @@ class RestSource:
     This class implements the HTTP query response handling.
     """
 
-    global _protocol, _hostname, _path
-    _protocol = "http://"
-    _hostname = "www.bibsonomy.org"
-    _path     = "/api"
 
     global _MAX_POSTS_PER_REQUEST
     _MAX_POSTS_PER_REQUEST = 1000
 
 
-    def __init__(self, user_name, api_key, data_format="json"):
+    def __init__(self, user_name, api_key, data_format="json", protocol="https", hostname="www.bibsonomy.org", path="/api"):
         """
         Initializes the class.
 
         data_format -- "xml" or "json" (default "json")
         """
-        self.http = httplib2.Http(".cache")
-        self.http.add_credentials(user_name, api_key)
+        self.auth = HTTPBasicAuth(user_name, api_key)
         self.format = data_format
+        self.protocol = protocol
+        self.hostname = hostname
+        self.path = path
 
     def get_max_posts_per_request(self):
         """
@@ -419,16 +418,13 @@ class RestSource:
         else:
             delim = "?"
         
-        url = _protocol + _hostname + _path + path + delim + "format=" + self.format
-        # print("calling " + url)
+        url = self.protocol + "://" + self.hostname + self.path + path + delim + "format=" + self.format
 
-        response,content = self.http.request(url, "GET")
-        if (response.status == 200):
-            str_content = content.decode("utf-8") #  TODO: get from header
-
-            return str_content
+        response = requests.get(url, auth=self.auth)
+        if (response.status_code == 200):
+            return response.text
         else:
-            raise HttpError(response.status, content)
+            raise HttpError(response.status_code, response.text)
 
     def getPostsForUser(self, resource_type, user_name, tags, start=0, end=_MAX_POSTS_PER_REQUEST):
         """
@@ -463,17 +459,17 @@ class RestSource:
 
     # TODO: use streaming!
     def getDocument(self, document):
-        response, content = self.http.request(document.href, "GET")
-        if response.status == 200:
-            return content, response['content-type']
+        response = requests.get(document.href, auth=self.auth)
+        if response.status_code == 200:
+            return response.content, response.headers['content-type']
         return None, None
         
 
     def getDocumentPreview(self, document, size):
-        response, content = self.http.request(document.href + "?preview=" + size, "GET")
-        if response.status == 200:
+        response = requests.get(document.href + "?preview=" + size, auth=self.auth)
+        if response.status_code == 200:
             # TODO: content type broken at the moment, returning default instead of response['content-type']
-            return content, "image/jpeg" 
+            return response.content, "image/jpeg" 
         return None
 
     def getUser(self, user_name):
